@@ -164,7 +164,7 @@ class RESTResourceMixin:
         Field values can be obtained from resource or core.
         """
 
-        method =  super().get_method_returning_field_value(field_name)
+        method = super().get_method_returning_field_value(field_name)
 
         if method:
             return method
@@ -414,7 +414,7 @@ class RESTModelResource(FieldPermissionViewMixin, RESTModelCoreMixin, RESTResour
     def patch(self):
         return super(RESTModelResource, self).patch() if self.kwargs.get(self.pk_name) else self.update_bulk()
 
-    @transaction.atomic
+    @transaction.smart_atomic
     def update_bulk(self):
         qs = self._filter_queryset(self._get_queryset())
         BULK_CHANGE_LIMIT = getattr(settings, 'BULK_CHANGE_LIMIT', 200)
